@@ -398,7 +398,7 @@ def Deployer(app: Callable[[], reacton.core.Element]):
     disable_view = (deploy_request and not online) or (not deploy_request and app_status != AppStatus.RUNNING)
     should_use_embed.provide(False)
     with v.Sheet() as main:
-        with v.Dialog(v_model=open_preview, on_v_model=set_open_preview, fullscreen=True, hide_overlay=True):
+        with v.Dialog(v_model=open_preview, on_v_model=set_open_preview, fullscreen=True, hide_overlay=True, persistent=True, no_click_animation=True):
             with v.Sheet(class_="overflow-y-auto overflow-x-auto"):
                 with solara.AppLayout():
                     with solara.AppBar():
